check_prev_add() always has save_trace() as an input argument, which is
unnecessary, so remove it.

Signed-off-by: Yuyang Du <duyuy...@gmail.com>
Reviewed-by: Bart Van Assche <bvanass...@acm.org>
---
 kernel/locking/lockdep.c | 11 +++++------
 1 file changed, 5 insertions(+), 6 deletions(-)

diff --git a/kernel/locking/lockdep.c b/kernel/locking/lockdep.c
index eccfb0b..f46695a 100644
--- a/kernel/locking/lockdep.c
+++ b/kernel/locking/lockdep.c
@@ -2193,8 +2193,7 @@ static inline void inc_chains(void)
  */
 static int
 check_prev_add(struct task_struct *curr, struct held_lock *prev,
-              struct held_lock *next, int distance, struct stack_trace *trace,
-              int (*save)(struct stack_trace *trace))
+              struct held_lock *next, int distance, struct stack_trace *trace)
 {
        struct lock_list *uninitialized_var(target_entry);
        struct lock_list *entry;
@@ -2234,11 +2233,11 @@ static inline void inc_chains(void)
        if (unlikely(!ret)) {
                if (!trace->entries) {
                        /*
                         * If @save fails here, the printing might trigger
                         * a WARN but because of the !nr_entries it should
                         * not do bad things.
                         */
-                       save(trace);
+                       save_trace(trace);
                }
                print_circular_bug(&this, target_entry, next, prev, trace);
                return 0;
@@ -2293,7 +2292,7 @@ static inline void inc_chains(void)
        }
 
 
-       if (!trace->entries && !save(trace))
+       if (!trace->entries && !save_trace(trace))
                return 0;
 
        /*
@@ -2358,7 +2357,7 @@ static inline void inc_chains(void)
                 * added:
                 */
                if (hlock->read != 2 && hlock->check) {
-                       int ret = check_prev_add(curr, hlock, next, distance, 
&trace, save_trace);
+                       int ret = check_prev_add(curr, hlock, next, distance, 
&trace);
                        if (!ret)
                                return 0;
@@ -2234,11 +2233,11 @@ static inline void inc_chains(void)
                if (!trace->entries) {
                        /*
-                        * If @save fails here, the printing might trigger
+                        * If save_trace fails here, the printing might trigger
                         * a WARN but because of the !nr_entries it should
                         * not do bad things.
 
-- 
1.8.3.1

Reply via email to